Method: Aws::MemoryDB::Types::DescribeClustersResponse#next_token

Defined in:
lib/aws-sdk-memorydb/types.rb

#next_tokenString

An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged.

Returns:

  • (String)


1362
1363
1364
1365
1366
1367
# File 'lib/aws-sdk-memorydb/types.rb', line 1362

class DescribeClustersResponse < Struct.new(
  :next_token,
  :clusters)
  SENSITIVE = []
  include Aws::Structure
end