Method: Aws::MemoryDB::Types::DescribeParameterGroupsResponse#next_token

Defined in:
lib/aws-sdk-memorydb/types.rb

#next_tokenString

An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged.



1709
1710
1711
1712
1713
1714
# File 'lib/aws-sdk-memorydb/types.rb', line 1709

class DescribeParameterGroupsResponse < Struct.new(
  :next_token,
  :parameter_groups)
  SENSITIVE = []
  include Aws::Structure
end