Class: Aws::MemoryDB::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MemoryDB::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-memorydb/client.rb,
sig/client.rbs
Overview
An API client for MemoryDB. To construct a client, you need to configure a :region and :credentials.
client = Aws::MemoryDB::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchUpdateClusterResponseSuccess, _CopySnapshotResponseSuccess, _CreateACLResponseSuccess, _CreateClusterResponseSuccess, _CreateMultiRegionClusterResponseSuccess, _CreateParameterGroupResponseSuccess, _CreateSnapshotResponseSuccess, _CreateSubnetGroupResponseSuccess, _CreateUserResponseSuccess, _DeleteACLResponseSuccess, _DeleteClusterResponseSuccess, _DeleteMultiRegionClusterResponseSuccess, _DeleteParameterGroupResponseSuccess, _DeleteSnapshotResponseSuccess, _DeleteSubnetGroupResponseSuccess, _DeleteUserResponseSuccess, _DescribeACLsResponseSuccess, _DescribeClustersResponseSuccess, _DescribeEngineVersionsResponseSuccess, _DescribeEventsResponseSuccess, _DescribeMultiRegionClustersResponseSuccess, _DescribeMultiRegionParameterGroupsResponseSuccess, _DescribeMultiRegionParametersResponseSuccess, _DescribeParameterGroupsResponseSuccess, _DescribeParametersResponseSuccess, _DescribeReservedNodesOfferingsResponseSuccess, _DescribeReservedNodesResponseSuccess, _DescribeServiceUpdatesResponseSuccess, _DescribeSnapshotsResponseSuccess, _DescribeSubnetGroupsResponseSuccess, _DescribeUsersResponseSuccess, _FailoverShardResponseSuccess, _ListAllowedMultiRegionClusterUpdatesResponseSuccess, _ListAllowedNodeTypeUpdatesResponseSuccess, _ListTagsResponseSuccess, _PurchaseReservedNodesOfferingResponseSuccess, _ResetParameterGroupResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateACLResponseSuccess, _UpdateClusterResponseSuccess, _UpdateMultiRegionClusterResponseSuccess, _UpdateParameterGroupResponseSuccess, _UpdateSubnetGroupResponseSuccess, _UpdateUserResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_update_cluster(params = {}) ⇒ Types::BatchUpdateClusterResponse
Apply the service update to a list of clusters supplied.
-
#copy_snapshot(params = {}) ⇒ Types::CopySnapshotResponse
Makes a copy of an existing snapshot.
-
#create_acl(params = {}) ⇒ Types::CreateACLResponse
Creates an Access Control List.
-
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Creates a cluster.
-
#create_multi_region_cluster(params = {}) ⇒ Types::CreateMultiRegionClusterResponse
Creates a new multi-Region cluster.
-
#create_parameter_group(params = {}) ⇒ Types::CreateParameterGroupResponse
Creates a new MemoryDB parameter group.
-
#create_snapshot(params = {}) ⇒ Types::CreateSnapshotResponse
Creates a copy of an entire cluster at a specific moment in time.
-
#create_subnet_group(params = {}) ⇒ Types::CreateSubnetGroupResponse
Creates a subnet group.
-
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a MemoryDB user.
-
#delete_acl(params = {}) ⇒ Types::DeleteACLResponse
Deletes an Access Control List.
-
#delete_cluster(params = {}) ⇒ Types::DeleteClusterResponse
Deletes a cluster.
-
#delete_multi_region_cluster(params = {}) ⇒ Types::DeleteMultiRegionClusterResponse
Deletes an existing multi-Region cluster.
-
#delete_parameter_group(params = {}) ⇒ Types::DeleteParameterGroupResponse
Deletes the specified parameter group.
-
#delete_snapshot(params = {}) ⇒ Types::DeleteSnapshotResponse
Deletes an existing snapshot.
-
#delete_subnet_group(params = {}) ⇒ Types::DeleteSubnetGroupResponse
Deletes a subnet group.
-
#delete_user(params = {}) ⇒ Types::DeleteUserResponse
Deletes a user.
-
#describe_acls(params = {}) ⇒ Types::DescribeACLsResponse
Returns a list of ACLs.
-
#describe_clusters(params = {}) ⇒ Types::DescribeClustersResponse
Returns information about all provisioned clusters if no cluster identifier is specified, or about a specific cluster if a cluster name is supplied.
-
#describe_engine_versions(params = {}) ⇒ Types::DescribeEngineVersionsResponse
Returns a list of the available Redis OSS engine versions.
-
#describe_events(params = {}) ⇒ Types::DescribeEventsResponse
Returns events related to clusters, security groups, and parameter groups.
-
#describe_multi_region_clusters(params = {}) ⇒ Types::DescribeMultiRegionClustersResponse
Returns details about one or more multi-Region clusters.
-
#describe_multi_region_parameter_groups(params = {}) ⇒ Types::DescribeMultiRegionParameterGroupsResponse
Returns a list of multi-region parameter groups.
-
#describe_multi_region_parameters(params = {}) ⇒ Types::DescribeMultiRegionParametersResponse
Returns the detailed parameter list for a particular multi-region parameter group.
-
#describe_parameter_groups(params = {}) ⇒ Types::DescribeParameterGroupsResponse
Returns a list of parameter group descriptions.
-
#describe_parameters(params = {}) ⇒ Types::DescribeParametersResponse
Returns the detailed parameter list for a particular parameter group.
-
#describe_reserved_nodes(params = {}) ⇒ Types::DescribeReservedNodesResponse
Returns information about reserved nodes for this account, or about a specified reserved node.
-
#describe_reserved_nodes_offerings(params = {}) ⇒ Types::DescribeReservedNodesOfferingsResponse
Lists available reserved node offerings.
-
#describe_service_updates(params = {}) ⇒ Types::DescribeServiceUpdatesResponse
Returns details of the service updates.
-
#describe_snapshots(params = {}) ⇒ Types::DescribeSnapshotsResponse
Returns information about cluster snapshots.
-
#describe_subnet_groups(params = {}) ⇒ Types::DescribeSubnetGroupsResponse
Returns a list of subnet group descriptions.
-
#describe_users(params = {}) ⇒ Types::DescribeUsersResponse
Returns a list of users.
-
#failover_shard(params = {}) ⇒ Types::FailoverShardResponse
Used to failover a shard.
-
#list_allowed_multi_region_cluster_updates(params = {}) ⇒ Types::ListAllowedMultiRegionClusterUpdatesResponse
Lists the allowed updates for a multi-Region cluster.
-
#list_allowed_node_type_updates(params = {}) ⇒ Types::ListAllowedNodeTypeUpdatesResponse
Lists all available node types that you can scale to from your cluster's current node type.
-
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Lists all tags currently on a named resource.
-
#purchase_reserved_nodes_offering(params = {}) ⇒ Types::PurchaseReservedNodesOfferingResponse
Allows you to purchase a reserved node offering.
-
#reset_parameter_group(params = {}) ⇒ Types::ResetParameterGroupResponse
Modifies the parameters of a parameter group to the engine or system default value.
-
#tag_resource(params = {}) ⇒ Types::TagResourceResponse
Use this operation to add tags to a resource.
-
#untag_resource(params = {}) ⇒ Types::UntagResourceResponse
Use this operation to remove tags on a resource.
-
#update_acl(params = {}) ⇒ Types::UpdateACLResponse
Changes the list of users that belong to the Access Control List.
-
#update_cluster(params = {}) ⇒ Types::UpdateClusterResponse
Modifies the settings for a cluster.
-
#update_multi_region_cluster(params = {}) ⇒ Types::UpdateMultiRegionClusterResponse
Updates the configuration of an existing multi-Region cluster.
-
#update_parameter_group(params = {}) ⇒ Types::UpdateParameterGroupResponse
Updates the parameters of a parameter group.
-
#update_subnet_group(params = {}) ⇒ Types::UpdateSubnetGroupResponse
Updates a subnet group.
-
#update_user(params = {}) ⇒ Types::UpdateUserResponse
Changes user password(s) and/or access string.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-memorydb/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3558 3559 3560 |
# File 'lib/aws-sdk-memorydb/client.rb', line 3558 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3561 3562 3563 |
# File 'lib/aws-sdk-memorydb/client.rb', line 3561 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_update_cluster(params = {}) ⇒ Types::BatchUpdateClusterResponse
Apply the service update to a list of clusters supplied. For more information on service updates and applying them, see Applying the service updates.
88 |
# File 'sig/client.rbs', line 88
def batch_update_cluster: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 3542 3543 3544 3545 3546 3547 |
# File 'lib/aws-sdk-memorydb/client.rb', line 3531 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MemoryDB') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-memorydb' context[:gem_version] = '1.65.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_snapshot(params = {}) ⇒ Types::CopySnapshotResponse
Makes a copy of an existing snapshot.
101 |
# File 'sig/client.rbs', line 101
def copy_snapshot: (
|
#create_acl(params = {}) ⇒ Types::CreateACLResponse
Creates an Access Control List. For more information, see Authenticating users with Access Contol Lists (ACLs).
120 |
# File 'sig/client.rbs', line 120
def create_acl: (
|
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Creates a cluster. All nodes in the cluster run the same protocol-compliant engine software.
137 |
# File 'sig/client.rbs', line 137
def create_cluster: (
|
#create_multi_region_cluster(params = {}) ⇒ Types::CreateMultiRegionClusterResponse
Creates a new multi-Region cluster.
177 |
# File 'sig/client.rbs', line 177
def create_multi_region_cluster: (
|
#create_parameter_group(params = {}) ⇒ Types::CreateParameterGroupResponse
Creates a new MemoryDB parameter group. A parameter group is a collection of parameters and their values that are applied to all of the nodes in any cluster. For more information, see Configuring engine parameters using parameter groups.
200 |
# File 'sig/client.rbs', line 200
def create_parameter_group: (
|
#create_snapshot(params = {}) ⇒ Types::CreateSnapshotResponse
Creates a copy of an entire cluster at a specific moment in time.
218 |
# File 'sig/client.rbs', line 218
def create_snapshot: (
|
#create_subnet_group(params = {}) ⇒ Types::CreateSubnetGroupResponse
Creates a subnet group. A subnet group is a collection of subnets (typically private) that you can designate for your clusters running in an Amazon Virtual Private Cloud (VPC) environment. When you create a cluster in an Amazon VPC, you must specify a subnet group. MemoryDB uses that subnet group to choose a subnet and IP addresses within that subnet to associate with your nodes. For more information, see Subnets and subnet groups.
236 |
# File 'sig/client.rbs', line 236
def create_subnet_group: (
|
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a MemoryDB user. For more information, see Authenticating users with Access Contol Lists (ACLs).
254 |
# File 'sig/client.rbs', line 254
def create_user: (
|
#delete_acl(params = {}) ⇒ Types::DeleteACLResponse
Deletes an Access Control List. The ACL must first be disassociated from the cluster before it can be deleted. For more information, see Authenticating users with Access Contol Lists (ACLs).
275 |
# File 'sig/client.rbs', line 275
def delete_acl: (
|
#delete_cluster(params = {}) ⇒ Types::DeleteClusterResponse
Deletes a cluster. It also deletes all associated nodes and node endpoints.
CreateSnapshot permission is required to create a final snapshot.
Without this permission, the API call will fail with an Access Denied exception.
285 |
# File 'sig/client.rbs', line 285
def delete_cluster: (
|
#delete_multi_region_cluster(params = {}) ⇒ Types::DeleteMultiRegionClusterResponse
Deletes an existing multi-Region cluster.
297 |
# File 'sig/client.rbs', line 297
def delete_multi_region_cluster: (
|
#delete_parameter_group(params = {}) ⇒ Types::DeleteParameterGroupResponse
Deletes the specified parameter group. You cannot delete a parameter group if it is associated with any clusters. You cannot delete the default parameter groups in your account.
307 |
# File 'sig/client.rbs', line 307
def delete_parameter_group: (
|
#delete_snapshot(params = {}) ⇒ Types::DeleteSnapshotResponse
Deletes an existing snapshot. When you receive a successful response from this operation, MemoryDB immediately begins deleting the snapshot; you cannot cancel or revert this operation.
317 |
# File 'sig/client.rbs', line 317
def delete_snapshot: (
|
#delete_subnet_group(params = {}) ⇒ Types::DeleteSubnetGroupResponse
Deletes a subnet group. You cannot delete a default subnet group or one that is associated with any clusters.
327 |
# File 'sig/client.rbs', line 327
def delete_subnet_group: (
|
#delete_user(params = {}) ⇒ Types::DeleteUserResponse
Deletes a user. The user will be removed from all ACLs and in turn removed from all clusters.
337 |
# File 'sig/client.rbs', line 337
def delete_user: (
|
#describe_acls(params = {}) ⇒ Types::DescribeACLsResponse
Returns a list of ACLs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
348 |
# File 'sig/client.rbs', line 348
def describe_acls: (
|
#describe_clusters(params = {}) ⇒ Types::DescribeClustersResponse
Returns information about all provisioned clusters if no cluster identifier is specified, or about a specific cluster if a cluster name is supplied.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
361 |
# File 'sig/client.rbs', line 361
def describe_clusters: (
|
#describe_engine_versions(params = {}) ⇒ Types::DescribeEngineVersionsResponse
Returns a list of the available Redis OSS engine versions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
375 |
# File 'sig/client.rbs', line 375
def describe_engine_versions: (
|
#describe_events(params = {}) ⇒ Types::DescribeEventsResponse
Returns events related to clusters, security groups, and parameter groups. You can obtain events specific to a particular cluster, security group, or parameter group by providing the name as a parameter. By default, only the events occurring within the last hour are returned; however, you can retrieve up to 14 days' worth of events if necessary.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
391 |
# File 'sig/client.rbs', line 391
def describe_events: (
|
#describe_multi_region_clusters(params = {}) ⇒ Types::DescribeMultiRegionClustersResponse
Returns details about one or more multi-Region clusters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
408 |
# File 'sig/client.rbs', line 408
def describe_multi_region_clusters: (
|
#describe_multi_region_parameter_groups(params = {}) ⇒ Types::DescribeMultiRegionParameterGroupsResponse
Returns a list of multi-region parameter groups.
422 |
# File 'sig/client.rbs', line 422
def describe_multi_region_parameter_groups: (
|
#describe_multi_region_parameters(params = {}) ⇒ Types::DescribeMultiRegionParametersResponse
Returns the detailed parameter list for a particular multi-region parameter group.
435 |
# File 'sig/client.rbs', line 435
def describe_multi_region_parameters: (
|
#describe_parameter_groups(params = {}) ⇒ Types::DescribeParameterGroupsResponse
Returns a list of parameter group descriptions. If a parameter group name is specified, the list contains only the descriptions for that group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
449 |
# File 'sig/client.rbs', line 449
def describe_parameter_groups: (
|
#describe_parameters(params = {}) ⇒ Types::DescribeParametersResponse
Returns the detailed parameter list for a particular parameter group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
462 |
# File 'sig/client.rbs', line 462
def describe_parameters: (
|
#describe_reserved_nodes(params = {}) ⇒ Types::DescribeReservedNodesResponse
Returns information about reserved nodes for this account, or about a specified reserved node.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
475 |
# File 'sig/client.rbs', line 475
def describe_reserved_nodes: (
|
#describe_reserved_nodes_offerings(params = {}) ⇒ Types::DescribeReservedNodesOfferingsResponse
Lists available reserved node offerings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
492 |
# File 'sig/client.rbs', line 492
def describe_reserved_nodes_offerings: (
|
#describe_service_updates(params = {}) ⇒ Types::DescribeServiceUpdatesResponse
Returns details of the service updates.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
508 |
# File 'sig/client.rbs', line 508
def describe_service_updates: (
|
#describe_snapshots(params = {}) ⇒ Types::DescribeSnapshotsResponse
Returns information about cluster snapshots. By default, DescribeSnapshots lists all of your snapshots; it can optionally describe a single snapshot, or just the snapshots associated with a particular cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
523 |
# File 'sig/client.rbs', line 523
def describe_snapshots: (
|
#describe_subnet_groups(params = {}) ⇒ Types::DescribeSubnetGroupsResponse
Returns a list of subnet group descriptions. If a subnet group name is specified, the list contains only the description of that group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
539 |
# File 'sig/client.rbs', line 539
def describe_subnet_groups: (
|
#describe_users(params = {}) ⇒ Types::DescribeUsersResponse
Returns a list of users.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
552 |
# File 'sig/client.rbs', line 552
def describe_users: (
|
#failover_shard(params = {}) ⇒ Types::FailoverShardResponse
Used to failover a shard. This API is designed for testing the behavior of your application in case of MemoryDB failover. It is not designed to be used as a production-level tool for initiating a failover to overcome a problem you may have with the cluster. Moreover, in certain conditions such as large scale operational events, Amazon may block this API.
570 |
# File 'sig/client.rbs', line 570
def failover_shard: (
|
#list_allowed_multi_region_cluster_updates(params = {}) ⇒ Types::ListAllowedMultiRegionClusterUpdatesResponse
Lists the allowed updates for a multi-Region cluster.
582 |
# File 'sig/client.rbs', line 582
def list_allowed_multi_region_cluster_updates: (
|
#list_allowed_node_type_updates(params = {}) ⇒ Types::ListAllowedNodeTypeUpdatesResponse
Lists all available node types that you can scale to from your cluster's current node type. When you use the UpdateCluster operation to scale your cluster, the value of the NodeType parameter must be one of the node types returned by this operation.
593 |
# File 'sig/client.rbs', line 593
def list_allowed_node_type_updates: (
|
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Lists all tags currently on a named resource. A tag is a key-value pair where the key and value are case-sensitive. You can use tags to categorize and track your MemoryDB resources. For more information, see Tagging your MemoryDB resources.
When you add or remove tags from multi region clusters, you might not immediately see the latest effective tags in the ListTags API response due to it being eventually consistent specifically for multi region clusters. For more information, see Tagging your MemoryDB resources.
603 |
# File 'sig/client.rbs', line 603
def list_tags: (
|
#purchase_reserved_nodes_offering(params = {}) ⇒ Types::PurchaseReservedNodesOfferingResponse
Allows you to purchase a reserved node offering. Reserved nodes are not eligible for cancellation and are non-refundable.
613 |
# File 'sig/client.rbs', line 613
def purchase_reserved_nodes_offering: (
|
#reset_parameter_group(params = {}) ⇒ Types::ResetParameterGroupResponse
Modifies the parameters of a parameter group to the engine or system default value. You can reset specific parameters by submitting a list of parameter names. To reset the entire parameter group, specify the AllParameters and ParameterGroupName parameters.
631 |
# File 'sig/client.rbs', line 631
def reset_parameter_group: (
|
#tag_resource(params = {}) ⇒ Types::TagResourceResponse
Use this operation to add tags to a resource. A tag is a key-value pair where the key and value are case-sensitive. You can use tags to categorize and track all your MemoryDB resources. For more information, see Tagging your MemoryDB resources.
When you add tags to multi region clusters, you might not immediately see the latest effective tags in the ListTags API response due to it being eventually consistent specifically for multi region clusters. For more information, see Tagging your MemoryDB resources.
You can specify cost-allocation tags for your MemoryDB resources, Amazon generates a cost allocation report as a comma-separated value (CSV) file with your usage and costs aggregated by your tags. You can apply tags that represent business categories (such as cost centers, application names, or owners) to organize your costs across multiple services. For more information, see Using Cost Allocation Tags.
643 |
# File 'sig/client.rbs', line 643
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Types::UntagResourceResponse
Use this operation to remove tags on a resource. A tag is a key-value pair where the key and value are case-sensitive. You can use tags to categorize and track all your MemoryDB resources. For more information, see Tagging your MemoryDB resources.
When you remove tags from multi region clusters, you might not immediately see the latest effective tags in the ListTags API response due to it being eventually consistent specifically for multi region clusters. For more information, see Tagging your MemoryDB resources.
You can specify cost-allocation tags for your MemoryDB resources, Amazon generates a cost allocation report as a comma-separated value (CSV) file with your usage and costs aggregated by your tags. You can apply tags that represent business categories (such as cost centers, application names, or owners) to organize your costs across multiple services. For more information, see Using Cost Allocation Tags.
659 |
# File 'sig/client.rbs', line 659
def untag_resource: (
|
#update_acl(params = {}) ⇒ Types::UpdateACLResponse
Changes the list of users that belong to the Access Control List.
670 |
# File 'sig/client.rbs', line 670
def update_acl: (
|
#update_cluster(params = {}) ⇒ Types::UpdateClusterResponse
Modifies the settings for a cluster. You can use this operation to change one or more cluster configuration settings by specifying the settings and the new values.
682 |
# File 'sig/client.rbs', line 682
def update_cluster: (
|
#update_multi_region_cluster(params = {}) ⇒ Types::UpdateMultiRegionClusterResponse
Updates the configuration of an existing multi-Region cluster.
711 |
# File 'sig/client.rbs', line 711
def update_multi_region_cluster: (
|
#update_parameter_group(params = {}) ⇒ Types::UpdateParameterGroupResponse
Updates the parameters of a parameter group. You can modify up to 20 parameters in a single request by submitting a list parameter name and value pairs.
729 |
# File 'sig/client.rbs', line 729
def update_parameter_group: (
|
#update_subnet_group(params = {}) ⇒ Types::UpdateSubnetGroupResponse
Updates a subnet group. For more information, see Updating a subnet group
745 |
# File 'sig/client.rbs', line 745
def update_subnet_group: (
|
#update_user(params = {}) ⇒ Types::UpdateUserResponse
Changes user password(s) and/or access string.
757 |
# File 'sig/client.rbs', line 757
def update_user: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3551 3552 3553 |
# File 'lib/aws-sdk-memorydb/client.rb', line 3551 def waiter_names [] end |