Class: Aws::MemoryDB::Types::ACL

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-memorydb/types.rb

Overview

An Access Control List. You can authenticate users with Access Contol Lists. ACLs enable you to control cluster access by grouping users. These Access control lists are designed as a way to organize access to clusters.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the ACL

Returns:

  • (String)


49
50
51
52
53
54
55
56
57
58
59
# File 'lib/aws-sdk-memorydb/types.rb', line 49

class ACL < Struct.new(
  :name,
  :status,
  :user_names,
  :minimum_engine_version,
  :pending_changes,
  :clusters,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#clusters ⇒ Array<String>

A list of clusters associated with the ACL.

Returns:

  • (Array<String>)


49
50
51
52
53
54
55
56
57
58
59
# File 'lib/aws-sdk-memorydb/types.rb', line 49

class ACL < Struct.new(
  :name,
  :status,
  :user_names,
  :minimum_engine_version,
  :pending_changes,
  :clusters,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#minimum_engine_version ⇒ String

The minimum engine version supported for the ACL

Returns:

  • (String)


49
50
51
52
53
54
55
56
57
58
59
# File 'lib/aws-sdk-memorydb/types.rb', line 49

class ACL < Struct.new(
  :name,
  :status,
  :user_names,
  :minimum_engine_version,
  :pending_changes,
  :clusters,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the Access Control List

Returns:

  • (String)


49
50
51
52
53
54
55
56
57
58
59
# File 'lib/aws-sdk-memorydb/types.rb', line 49

class ACL < Struct.new(
  :name,
  :status,
  :user_names,
  :minimum_engine_version,
  :pending_changes,
  :clusters,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#pending_changes ⇒ Types::ACLPendingChanges

A list of updates being applied to the ACL.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/aws-sdk-memorydb/types.rb', line 49

class ACL < Struct.new(
  :name,
  :status,
  :user_names,
  :minimum_engine_version,
  :pending_changes,
  :clusters,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

Indicates ACL status. Can be "creating", "active", "modifying", "deleting".

Returns:

  • (String)


49
50
51
52
53
54
55
56
57
58
59
# File 'lib/aws-sdk-memorydb/types.rb', line 49

class ACL < Struct.new(
  :name,
  :status,
  :user_names,
  :minimum_engine_version,
  :pending_changes,
  :clusters,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#user_names ⇒ Array<String>

The list of user names that belong to the ACL.

Returns:

  • (Array<String>)


49
50
51
52
53
54
55
56
57
58
59
# File 'lib/aws-sdk-memorydb/types.rb', line 49

class ACL < Struct.new(
  :name,
  :status,
  :user_names,
  :minimum_engine_version,
  :pending_changes,
  :clusters,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end