Class: Aws::MemoryDB::Types::Cluster

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-memorydb/types.rb

Overview

Contains all of the attributes of a specific cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acl_name ⇒ String

The name of the Access Control List associated with this cluster.

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#arn ⇒ String

The Amazon Resource Name (ARN) of the cluster.

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#auto_minor_version_upgrade ⇒ Boolean

When set to true, the cluster will automatically receive minor engine version upgrades after launch.

Returns:

  • (Boolean)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#availability_mode ⇒ String

Indicates if the cluster has a Multi-AZ configuration (multiaz) or not (singleaz).

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_endpoint ⇒ Types::Endpoint

The cluster's configuration endpoint

Returns:



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#data_tiering ⇒ String

Enables data tiering. Data tiering is only supported for clusters using the r6gd node type. This parameter must be set when using r6gd nodes. For more information, see Data tiering.

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

A description of the cluster

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#engine ⇒ String

The name of the engine used by the cluster.

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#engine_patch_version ⇒ String

The Redis OSS engine patch version used by the cluster

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#engine_version ⇒ String

The Redis OSS engine version used by the cluster

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#ip_discovery ⇒ String

The mechanism that the cluster uses to discover IP addresses. Returns 'ipv4' when DNS endpoints resolve to IPv4 addresses, or 'ipv6' when DNS endpoints resolve to IPv6 addresses.

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_id ⇒ String

The ID of the KMS key used to encrypt the cluster

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_window ⇒ String

Specifies the weekly time range during which maintenance on the cluster is performed. It is specified as a range in the format ddd:hh24:mi-ddd:hh24:mi (24H Clock UTC). The minimum maintenance window is a 60 minute period.

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#multi_region_cluster_name ⇒ String

The name of the multi-Region cluster that this cluster belongs to.

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The user-supplied name of the cluster. This identifier is a unique key that identifies a cluster.

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#network_type ⇒ String

The IP address type for the cluster. Returns 'ipv4' for IPv4 only, 'ipv6' for IPv6 only, or 'dual-stack' if the cluster supports both IPv4 and IPv6 addressing.

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#node_type ⇒ String

The cluster's node type

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_shards ⇒ Integer

The number of shards in the cluster

Returns:

  • (Integer)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_group_name ⇒ String

The name of the parameter group used by the cluster

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_group_status ⇒ String

The status of the parameter group used by the cluster, for example 'active' or 'applying'.

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#pending_updates ⇒ Types::ClusterPendingUpdates

A group of settings that are currently being applied.



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#security_groups ⇒ Array<Types::SecurityGroupMembership>

A list of security groups used by the cluster

Returns:



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#shards ⇒ Array<Types::Shard>

A list of shards that are members of the cluster.

Returns:



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_retention_limit ⇒ Integer

The number of days for which MemoryDB retains automatic snapshots before deleting them. For example, if you set SnapshotRetentionLimit to 5, a snapshot that was taken today is retained for 5 days before being deleted.

Returns:

  • (Integer)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_window ⇒ String

The daily time range (in UTC) during which MemoryDB begins taking a daily snapshot of your shard. Example: 05:00-09:00 If you do not specify this parameter, MemoryDB automatically chooses an appropriate time range.

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#sns_topic_arn ⇒ String

The Amazon Resource Name (ARN) of the SNS notification topic

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#sns_topic_status ⇒ String

The SNS topic must be in Active status to receive notifications

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the cluster. For example, Available, Updating, Creating.

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_group_name ⇒ String

The name of the subnet group used by the cluster

Returns:

  • (String)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#tls_enabled ⇒ Boolean

A flag to indicate if In-transit encryption is enabled

Returns:

  • (Boolean)


358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/aws-sdk-memorydb/types.rb', line 358

class Cluster < Struct.new(
  :name,
  :description,
  :status,
  :pending_updates,
  :multi_region_cluster_name,
  :number_of_shards,
  :shards,
  :availability_mode,
  :cluster_endpoint,
  :node_type,
  :engine,
  :engine_version,
  :engine_patch_version,
  :parameter_group_name,
  :parameter_group_status,
  :security_groups,
  :subnet_group_name,
  :tls_enabled,
  :kms_key_id,
  :arn,
  :sns_topic_arn,
  :sns_topic_status,
  :snapshot_retention_limit,
  :maintenance_window,
  :snapshot_window,
  :acl_name,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end