Class: Aws::MemoryDB::Types::CreateClusterRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-memorydb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acl_name ⇒ String

The name of the Access Control List to associate with the cluster.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#auto_minor_version_upgrade ⇒ Boolean

When set to true, the cluster will automatically receive minor engine version upgrades after launch.

Returns:

  • (Boolean)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_name ⇒ String

The name of the cluster. This value must be unique as it also serves as the cluster identifier.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#data_tiering ⇒ Boolean

Enables data tiering. Data tiering is only supported for clusters using the r6gd node type. This parameter must be set when using r6gd nodes. For more information, see Data tiering.

Returns:

  • (Boolean)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

An optional description of the cluster.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#engine ⇒ String

The name of the engine to be used for the cluster.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#engine_version ⇒ String

The version number of the Redis OSS engine to be used for the cluster.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#ip_discovery ⇒ String

The mechanism for discovering IP addresses for the cluster discovery protocol. Valid values are 'ipv4' or 'ipv6'. When set to 'ipv4', cluster discovery functions such as cluster slots, cluster shards, and cluster nodes return IPv4 addresses for cluster nodes. When set to 'ipv6', the cluster discovery functions return IPv6 addresses for cluster nodes. The value must be compatible with the NetworkType parameter. If not specified, the default is 'ipv4'.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_id ⇒ String

The ID of the KMS key used to encrypt the cluster.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_window ⇒ String

Specifies the weekly time range during which maintenance on the cluster is performed. It is specified as a range in the format ddd:hh24:mi-ddd:hh24:mi (24H Clock UTC). The minimum maintenance window is a 60 minute period.

Valid values for ddd are:

  • sun

  • mon

  • tue

  • wed

  • thu

  • fri

  • sat

Example: sun:23:00-mon:01:30

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#multi_region_cluster_name ⇒ String

The name of the multi-Region cluster to be created.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#network_type ⇒ String

Specifies the IP address type for the cluster. Valid values are 'ipv4', 'ipv6', or 'dual_stack'. When set to 'ipv4', the cluster will only be accessible via IPv4 addresses. When set to 'ipv6', the cluster will only be accessible via IPv6 addresses. When set to 'dual_stack', the cluster will be accessible via both IPv4 and IPv6 addresses. If not specified, the default is 'ipv4'.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#node_type ⇒ String

The compute and memory capacity of the nodes in the cluster.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#num_replicas_per_shard ⇒ Integer

The number of replicas to apply to each shard. The default value is

  1. The maximum is 5.

Returns:

  • (Integer)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#num_shards ⇒ Integer

The number of shards the cluster will contain. The default value is 1.

Returns:

  • (Integer)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_group_name ⇒ String

The name of the parameter group associated with the cluster.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#port ⇒ Integer

The port number on which each of the nodes accepts connections.

Returns:

  • (Integer)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_ids ⇒ Array<String>

A list of security group names to associate with this cluster.

Returns:

  • (Array<String>)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_arns ⇒ Array<String>

A list of Amazon Resource Names (ARN) that uniquely identify the RDB snapshot files stored in Amazon S3. The snapshot files are used to populate the new cluster. The Amazon S3 object name in the ARN cannot contain any commas.

Returns:

  • (Array<String>)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_name ⇒ String

The name of a snapshot from which to restore data into the new cluster. The snapshot status changes to restoring while the new cluster is being created.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_retention_limit ⇒ Integer

The number of days for which MemoryDB retains automatic snapshots before deleting them. For example, if you set SnapshotRetentionLimit to 5, a snapshot that was taken today is retained for 5 days before being deleted.

Returns:

  • (Integer)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_window ⇒ String

The daily time range (in UTC) during which MemoryDB begins taking a daily snapshot of your shard.

Example: 05:00-09:00

If you do not specify this parameter, MemoryDB automatically chooses an appropriate time range.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#sns_topic_arn ⇒ String

The Amazon Resource Name (ARN) of the Amazon Simple Notification Service (SNS) topic to which notifications are sent.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_group_name ⇒ String

The name of the subnet group to be used for the cluster.

Returns:

  • (String)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

A list of tags to be added to this resource. Tags are comma-separated key,value pairs (e.g. Key=myKey, Value=myKeyValue. You can include multiple tags as shown following: Key=myKey, Value=myKeyValue Key=mySecondKey, Value=mySecondKeyValue.

Returns:



794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end

#tls_enabled ⇒ Boolean

A flag to enable in-transit encryption on the cluster.

Returns:

  • (Boolean)


794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-memorydb/types.rb', line 794

class CreateClusterRequest < Struct.new(
  :cluster_name,
  :node_type,
  :multi_region_cluster_name,
  :parameter_group_name,
  :description,
  :num_shards,
  :num_replicas_per_shard,
  :subnet_group_name,
  :security_group_ids,
  :maintenance_window,
  :port,
  :sns_topic_arn,
  :tls_enabled,
  :kms_key_id,
  :snapshot_arns,
  :snapshot_name,
  :snapshot_retention_limit,
  :tags,
  :snapshot_window,
  :acl_name,
  :engine,
  :engine_version,
  :auto_minor_version_upgrade,
  :data_tiering,
  :network_type,
  :ip_discovery)
  SENSITIVE = []
  include Aws::Structure
end