Class: Aws::MemoryDB::Types::CreateSubnetGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-memorydb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#description ⇒ String

A description for the subnet group.

Returns:

  • (String)


1011
1012
1013
1014
1015
1016
1017
1018
# File 'lib/aws-sdk-memorydb/types.rb', line 1011

class CreateSubnetGroupRequest < Struct.new(
  :subnet_group_name,
  :description,
  :subnet_ids,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_group_name ⇒ String

The name of the subnet group.

Returns:

  • (String)


1011
1012
1013
1014
1015
1016
1017
1018
# File 'lib/aws-sdk-memorydb/types.rb', line 1011

class CreateSubnetGroupRequest < Struct.new(
  :subnet_group_name,
  :description,
  :subnet_ids,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_ids ⇒ Array<String>

A list of VPC subnet IDs for the subnet group.

Returns:

  • (Array<String>)


1011
1012
1013
1014
1015
1016
1017
1018
# File 'lib/aws-sdk-memorydb/types.rb', line 1011

class CreateSubnetGroupRequest < Struct.new(
  :subnet_group_name,
  :description,
  :subnet_ids,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.

Returns:



1011
1012
1013
1014
1015
1016
1017
1018
# File 'lib/aws-sdk-memorydb/types.rb', line 1011

class CreateSubnetGroupRequest < Struct.new(
  :subnet_group_name,
  :description,
  :subnet_ids,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end