Class: Aws::MemoryDB::Types::DescribeMultiRegionParametersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-memorydb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_results ⇒ Integer

The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.

Returns:

  • (Integer)


1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-memorydb/types.rb', line 1633

class DescribeMultiRegionParametersRequest < Struct.new(
  :multi_region_parameter_group_name,
  :source,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#multi_region_parameter_group_name ⇒ String

The name of the multi-region parameter group to return details for.

Returns:

  • (String)


1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-memorydb/types.rb', line 1633

class DescribeMultiRegionParametersRequest < Struct.new(
  :multi_region_parameter_group_name,
  :source,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.

Returns:

  • (String)


1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-memorydb/types.rb', line 1633

class DescribeMultiRegionParametersRequest < Struct.new(
  :multi_region_parameter_group_name,
  :source,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#source ⇒ String

The parameter types to return. Valid values: user | system | engine-default

Returns:

  • (String)


1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-memorydb/types.rb', line 1633

class DescribeMultiRegionParametersRequest < Struct.new(
  :multi_region_parameter_group_name,
  :source,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end