Class: Aws::MemoryDB::Types::DescribeParameterGroupsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MemoryDB::Types::DescribeParameterGroupsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-memorydb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
An optional argument to pass in case the total number of records exceeds the value of MaxResults.
-
#parameter_groups ⇒ Array<Types::ParameterGroup>
A list of parameter groups.
Instance Attribute Details
#next_token ⇒ String
An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged.
1709 1710 1711 1712 1713 1714 |
# File 'lib/aws-sdk-memorydb/types.rb', line 1709 class DescribeParameterGroupsResponse < Struct.new( :next_token, :parameter_groups) SENSITIVE = [] include Aws::Structure end |
#parameter_groups ⇒ Array<Types::ParameterGroup>
A list of parameter groups. Each element in the list contains detailed information about one parameter group.
1709 1710 1711 1712 1713 1714 |
# File 'lib/aws-sdk-memorydb/types.rb', line 1709 class DescribeParameterGroupsResponse < Struct.new( :next_token, :parameter_groups) SENSITIVE = [] include Aws::Structure end |