Class: Aws::MemoryDB::Types::DescribeReservedNodesOfferingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-memorydb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#duration ⇒ String

Duration filter value, specified in years or seconds. Use this parameter to show only reservations for a given duration.

Returns:

  • (String)


1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
# File 'lib/aws-sdk-memorydb/types.rb', line 1812

class DescribeReservedNodesOfferingsRequest < Struct.new(
  :reserved_nodes_offering_id,
  :node_type,
  :duration,
  :offering_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved.

Returns:

  • (Integer)


1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
# File 'lib/aws-sdk-memorydb/types.rb', line 1812

class DescribeReservedNodesOfferingsRequest < Struct.new(
  :reserved_nodes_offering_id,
  :node_type,
  :duration,
  :offering_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
# File 'lib/aws-sdk-memorydb/types.rb', line 1812

class DescribeReservedNodesOfferingsRequest < Struct.new(
  :reserved_nodes_offering_id,
  :node_type,
  :duration,
  :offering_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#node_type ⇒ String

The node type for the reserved nodes. For more information, see Supported node types.

Returns:

  • (String)


1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
# File 'lib/aws-sdk-memorydb/types.rb', line 1812

class DescribeReservedNodesOfferingsRequest < Struct.new(
  :reserved_nodes_offering_id,
  :node_type,
  :duration,
  :offering_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#offering_type ⇒ String

The offering type filter value. Use this parameter to show only the available offerings matching the specified offering type. Valid values: "All Upfront"|"Partial Upfront"| "No Upfront"

Returns:

  • (String)


1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
# File 'lib/aws-sdk-memorydb/types.rb', line 1812

class DescribeReservedNodesOfferingsRequest < Struct.new(
  :reserved_nodes_offering_id,
  :node_type,
  :duration,
  :offering_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_nodes_offering_id ⇒ String

The offering identifier filter value. Use this parameter to show only the available offering that matches the specified reservation identifier.

Returns:

  • (String)


1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
# File 'lib/aws-sdk-memorydb/types.rb', line 1812

class DescribeReservedNodesOfferingsRequest < Struct.new(
  :reserved_nodes_offering_id,
  :node_type,
  :duration,
  :offering_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end