Class: Aws::MemoryDB::Types::DescribeReservedNodesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-memorydb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#duration ⇒ String

The duration filter value, specified in years or seconds. Use this parameter to show only reservations for this duration.

Returns:

  • (String)


1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-memorydb/types.rb', line 1891

class DescribeReservedNodesRequest < Struct.new(
  :reservation_id,
  :reserved_nodes_offering_id,
  :node_type,
  :duration,
  :offering_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved.

Returns:

  • (Integer)


1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-memorydb/types.rb', line 1891

class DescribeReservedNodesRequest < Struct.new(
  :reservation_id,
  :reserved_nodes_offering_id,
  :node_type,
  :duration,
  :offering_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-memorydb/types.rb', line 1891

class DescribeReservedNodesRequest < Struct.new(
  :reservation_id,
  :reserved_nodes_offering_id,
  :node_type,
  :duration,
  :offering_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#node_type ⇒ String

The node type filter value. Use this parameter to show only those reservations matching the specified node type. For more information, see Supported node types.

Returns:

  • (String)


1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-memorydb/types.rb', line 1891

class DescribeReservedNodesRequest < Struct.new(
  :reservation_id,
  :reserved_nodes_offering_id,
  :node_type,
  :duration,
  :offering_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#offering_type ⇒ String

The offering type filter value. Use this parameter to show only the available offerings matching the specified offering type. Valid values: "All Upfront"|"Partial Upfront"| "No Upfront"

Returns:

  • (String)


1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-memorydb/types.rb', line 1891

class DescribeReservedNodesRequest < Struct.new(
  :reservation_id,
  :reserved_nodes_offering_id,
  :node_type,
  :duration,
  :offering_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#reservation_id ⇒ String

The reserved node identifier filter value. Use this parameter to show only the reservation that matches the specified reservation ID.

Returns:

  • (String)


1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-memorydb/types.rb', line 1891

class DescribeReservedNodesRequest < Struct.new(
  :reservation_id,
  :reserved_nodes_offering_id,
  :node_type,
  :duration,
  :offering_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_nodes_offering_id ⇒ String

The offering identifier filter value. Use this parameter to show only purchased reservations matching the specified offering identifier.

Returns:

  • (String)


1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-memorydb/types.rb', line 1891

class DescribeReservedNodesRequest < Struct.new(
  :reservation_id,
  :reserved_nodes_offering_id,
  :node_type,
  :duration,
  :offering_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end