Class: Aws::MemoryDB::Types::TagResourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-memorydb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) of the resource to which the tags are to be added.

Returns:

  • (String)


3623
3624
3625
3626
3627
3628
# File 'lib/aws-sdk-memorydb/types.rb', line 3623

class TagResourceRequest < Struct.new(
  :resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.

Returns:



3623
3624
3625
3626
3627
3628
# File 'lib/aws-sdk-memorydb/types.rb', line 3623

class TagResourceRequest < Struct.new(
  :resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end