Method: Aws::MemoryDB::Types::DescribeParametersResponse#next_token
- Defined in:
- lib/aws-sdk-memorydb/types.rb
#next_token ⇒ String
An optional argument to pass in case the total number of records exceeds the value of MaxResults. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged.
1763 1764 1765 1766 1767 1768 |
# File 'lib/aws-sdk-memorydb/types.rb', line 1763 class DescribeParametersResponse < Struct.new( :next_token, :parameters) SENSITIVE = [] include Aws::Structure end |